Builtin Structural Tag
================================

.. currentmodule:: xgrammar.builtin_structural_tag

This page contains the API reference for the structural tag template function. For its usage, see
:doc:`Builtin Structural Tag Usage <../../tutorials/advanced_builtin_structural_tag>`.

.. autofunction::  get_builtin_structural_tag_supported_models

.. autofunction::  get_builtin_structural_tag

.. autodata:: BuiltinSupportedModels
